summaryrefslogtreecommitdiff
path: root/svtools/source/table
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-05-26 08:29:52 +0200
committerNoel Grandin <noel@peralex.com>2015-05-26 08:30:19 +0200
commit204d147b8a887d17e6457f795e8b8f4d632213ae (patch)
tree97d0bfc08eff025958add5731e96fbe44d84976e /svtools/source/table
parent79aa1ab00a8361c44b8caf73294f841e6553eb72 (diff)
convert SCROLL constants to scoped enum
Change-Id: I5696fa39b2d032735cea7abe039349d4f83cf68d
Diffstat (limited to 'svtools/source/table')
-rw-r--r--svtools/source/table/tablecontrol_impl.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/svtools/source/table/tablecontrol_impl.cxx b/svtools/source/table/tablecontrol_impl.cxx
index 916f7d8b824f..71c688f949fe 100644
--- a/svtools/source/table/tablecontrol_impl.cxx
+++ b/svtools/source/table/tablecontrol_impl.cxx
@@ -2082,7 +2082,7 @@ namespace svt { namespace table
&& std::abs( nPixelDelta ) < aDataArea.GetHeight()
)
{
- m_pDataWindow->Scroll( 0, (long)-nPixelDelta, aDataArea, SCROLL_CLIP | SCROLL_UPDATE | SCROLL_CHILDREN);
+ m_pDataWindow->Scroll( 0, (long)-nPixelDelta, aDataArea, ScrollFlags::Clip | ScrollFlags::Update | ScrollFlags::Children);
}
else
{
@@ -2145,7 +2145,7 @@ namespace svt { namespace table
- m_aColumnWidths[ m_nLeftColumn ].getStart();
// update our column positions
// Do this *before* scrolling, as SCROLL_UPDATE will trigger a paint, which already needs the correct
// information in m_aColumnWidths
for ( ColumnPositions::iterator colPos = m_aColumnWidths.begin();
colPos != m_aColumnWidths.end();
@@ -2160,7 +2160,7 @@ namespace svt { namespace table
&& std::abs( nPixelDelta ) < aDataArea.GetWidth()
)
{
- m_pDataWindow->Scroll( nPixelDelta, 0, aDataArea, SCROLL_CLIP | SCROLL_UPDATE );
+ m_pDataWindow->Scroll( nPixelDelta, 0, aDataArea, ScrollFlags::Clip | ScrollFlags::Update );
}
else
{
@@ -2145,7 +2145,7 @@ namespace svt { namespace table
// update our column positions
- // Do this *before* scrolling, as SCROLL_UPDATE will trigger a paint, which already needs the correct
+ // Do this *before* scrolling, as ScrollFlags::Update will trigger a paint, which already needs the correct
// information in m_aColumnWidths
for ( ColumnPositions::iterator colPos = m_aColumnWidths.begin();